# CT Snippets

A package for improving College Track's data workflow. This package has three primary functions: 

- Streamline common task such as shortening site and region's names.
- Creating a smoother process for downloading data from Salesforce or Big Query
- Making uploading data to Salesforce a painfree process. 

This package is currently designed to work in conjunction with [CT Cookie Cutter](https://github.com/College-Track/ct_cookie_cutter)


